==> vradi-swing-0.0.2-sources.jar: com/jurismarches/vradi/ui/RequestFormViewHandler.java <==
/*
 * *##% 
 * vradi-swing
 * Copyright (C) 2009 JurisMarches
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * ##%*
 */
/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package com.jurismarches.vradi.ui;

import jaxx.runtime.JAXXContext;
import jaxx.runtime.context.JAXXInitialContext;

/**
 * @author letellier
 */
public class RequestFormViewHandler {

    /**
     * Methode pour initialiser l'ui principale sans l'afficher.
     *
     * @param rootContext le context applicatif
     * @return l'ui instancie et initialisee mais non visible encore
     */
    public RequestFormViewUI initUI(JAXXContext rootContext) {

        JAXXInitialContext context = new JAXXInitialContext().add(rootContext);

        // show main ui
        context.add(this);
        RequestFormViewUI ui = new RequestFormViewUI(context);

//        VradiContext.OFFERT_LIST_UI_ENTRY_DEF.setContextValue(context, ui);

        return ui;
    }

    RequestFormViewUI getUI(JAXXContext context) {
        if (context instanceof RequestFormViewUI) {
            return (RequestFormViewUI) context;
        }
//        OfferListUI ui = VradiContext.OFFERT_LIST_UI_ENTRY_DEF.getContextValue(context);
        return null;
    }

    void close(JAXXContext context) {
        RequestFormViewUI ui = getUI(context);
        ui.setVisible(false);
        ui.dispose();
    }
}

==> vradi-swing-0.0.3-sources.jar: com/jurismarches/vradi/ui/RequestFormViewHandler.java <==
/*
 * *##% 
 * vradi-swing
 * Copyright (C) 2009 JurisMarches
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * ##%*
 */
/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package com.jurismarches.vradi.ui;

import jaxx.runtime.JAXXContext;
import jaxx.runtime.context.JAXXInitialContext;

/**
 * @author letellier
 */
public class RequestFormViewHandler {

    /**
     * Methode pour initialiser l'ui principale sans l'afficher.
     *
     * @param rootContext le context applicatif
     * @return l'ui instancie et initialisee mais non visible encore
     */
    public RequestFormViewUI initUI(JAXXContext rootContext) {

        JAXXInitialContext context = new JAXXInitialContext().add(rootContext).add(this);

        // show main ui
        RequestFormViewUI ui = new RequestFormViewUI(context);

//        VradiContext.OFFERT_LIST_UI_ENTRY_DEF.setContextValue(context, ui);

        return ui;
    }

    RequestFormViewUI getUI(JAXXContext context) {
        if (context instanceof RequestFormViewUI) {
            return (RequestFormViewUI) context;
        }
//        OfferListUI ui = VradiContext.OFFERT_LIST_UI_ENTRY_DEF.getContextValue(context);
        return null;
    }

    void close(JAXXContext context) {
        RequestFormViewUI ui = getUI(context);
        ui.setVisible(false);
        ui.dispose();
    }
}
